> ⚠️ **This is a WIP!** API and features may change 

# React Media Components

**React Media Components** is a library with the goal to provide easy to use, portable and fast media components for your React app. 

**Key features**
- 🌄 **Image component** to render images in a picture tag with all the required formats and sizes.

_**Coming soon**_
- _🎬 **Video component** to render videos with a video tag using next gen formats and different resolutions._
- _🔊 **Audio component** to render audio files in a audio tag using next gen formats and different sound qualities._

## Installation
```bash
npm install react-media-components
# or 
yarn add react-media-components
```

## Usage
To use the image component you can simply import it and return it in your component. You can use `sizes` and `formats` props to render the image in the formats and sizes you need. You can also apply any known [img attributes](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img#attributes) you want, like for example `alt` or `style`.
```jsx
import { Image } from "react-media-components";

const YourComponent = () => {
  return (
    <Image src="/path/to/image.png" sizes={[375, 768, 1024]} formats={["WebP", "AVIF", "PNG"]} alt="foobar" />
  );
};
```

The example above renders the following "HTML":
```html
<picture>
  <source media="(min-width:1024px)" srcset="image-1024.avif" type="image/avif" />
  <source media="(min-width:1024px)" srcset="image-1024.webp" type="image/webp" />
  <source media="(min-width:1024px)" srcset="image-1024.png" type="image/png" />

  <source media="(min-width:768px)" srcset="image-768.avif" type="image/avif" />
  <source media="(min-width:768px)" srcset="image-768.webp" type="image/webp" />
  <source media="(min-width:768px)" srcset="image-768.png" type="image/png" />

  <source media="(min-width:375px)" srcset="image-375.avif" type="image/avif" />
  <source media="(min-width:375px)" srcset="image-375.webp" type="image/webp" />
  <source media="(min-width:375px)" srcset="image-375.png" type="image/png" />

  <source srcset="image.avif" type="image/avif" />
  <source srcset="image.webp" type="image/webp" />
  <img src="image.avif" alt="foobar" />
</picture>
```

## Props
| Attributes | Type | Default | Description |
| --- | --- | --- | --- |
| src | `string` | `null` | Source of your image |
| formats | `Array<"AVIF" \| "WebP" \| "JPEG" \| "PNG">` | `["AVIF", "WebP", src format]` | The formats your image will be rendered in |
| sizes | `Array<number>` | `[375, 768, 1024]` | The sizes your image will render in  |

## 


## Contributers
[![](https://github.com/faessler.png?size=50)](https://github.com/faessler)
[![](https://github.com/sirtobey.png?size=50)](https://github.com/sirtobey)
[![](https://github.com/wityan.png?size=50)](https://github.com/wityan)


NOTES:
- What about high resolution?
- Is it possible to just use a image tag instead of picture with source tags? Would safe space?
- How do we apply width and height? Should be applied, right? `<source media="(min-width:768px)" srcset="image-768.avif" type="image/avif" width="768" height="xyz" />`
